@@ -1,8 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-__version__ = '0.3.3'
-
 import re
 
 def literalize_string(content, is_unicode=False):
@@ -71,6 +69,9 @@ def unescape(b, encoding):
 def make_unistream(stream):
     '''Make a stream which unescapes string literals before writes out.'''
 
+    if not stream.isatty():
+        return stream
+
     unistream = lambda: 'I am an unistream!'
 
     # make unistream look like the stream
